@@ -116,6 +116,11 @@ common_args = [
         "action": 'store_true',
         "default": False,
     }),
+    (["--verbose"], {
+        "help": "show extra detail in debug log; used with --debug",
+        "action": 'store_true',
+        "default": False,
+    }),
 ]
 
 # Arguments added to commands which require authentication
@@ -254,7 +259,13 @@ TUI_COMMANDS = [
     Command(
         name="tui",
         description="Launches the toot terminal user interface",
-        arguments=[],
+        arguments=[
+            (["--relative-datetimes"], {
+                "action": "store_true",
+                "default": False,
+                "help": "Show relative datetimes in status list.",
+            }),
+        ],
         require_auth=True,
     ),
 ]
@@ -669,11 +680,12 @@ def main():
     if "--debug" in sys.argv:
         filename = os.getenv("TOOT_LOG_FILE")
         logging.basicConfig(level=logging.DEBUG, filename=filename)
+        logging.getLogger("urllib3").setLevel(logging.INFO)
 
     command_name = sys.argv[1] if len(sys.argv) > 1 else None
     args = sys.argv[2:]
 
-    if not command_name:
+    if not command_name or command_name == "--help":
         return print_usage()
 
     user, app = config.get_active_user_app()
