@@ -11,7 +11,7 @@ from .compose import StatusComposer
 from .constants import PALETTE
 from .entities import Status
 from .overlays import ExceptionStackTrace, GotoMenu, Help, StatusSource, StatusLinks, StatusZoom
-from .overlays import StatusDeleteConfirmation
+from .overlays import StatusDeleteConfirmation, Account
 from .timeline import Timeline
 from .utils import parse_content_links, show_media
 
@@ -73,10 +73,10 @@ class TUI(urwid.Frame):
     """Main TUI frame."""
 
     @classmethod
-    def create(cls, app, user):
+    def create(cls, app, user, args):
         """Factory method, sets up TUI and an event loop."""
 
-        tui = cls(app, user)
+        tui = cls(app, user, args)
         loop = urwid.MainLoop(
             tui,
             palette=PALETTE,
@@ -87,9 +87,10 @@ class TUI(urwid.Frame):
 
         return tui
 
-    def __init__(self, app, user):
+    def __init__(self, app, user, args):
         self.app = app
         self.user = user
+        self.args = args
         self.config = config.load_config()
 
         self.loop = None  # set in `create`
@@ -174,6 +175,9 @@ class TUI(urwid.Frame):
         return future
 
     def connect_default_timeline_signals(self, timeline):
+        def _account(timeline, account_id):
+            self.show_account(account_id)
+
         def _compose(*args):
             self.show_compose()
 
@@ -202,6 +206,7 @@ class TUI(urwid.Frame):
         def _clear(*args):
             self.clear_screen()
 
+        urwid.connect_signal(timeline, "account", _account)
         urwid.connect_signal(timeline, "bookmark", self.async_toggle_bookmark)
         urwid.connect_signal(timeline, "compose", _compose)
         urwid.connect_signal(timeline, "delete", _delete)
@@ -336,7 +341,8 @@ class TUI(urwid.Frame):
                 # this works for Mastodon and Pleroma version strings
                 # Mastodon versions < 4 do not have translation service
                 # Revisit this logic if Pleroma implements translation
-                self.can_translate = int(instance["version"][0]) > 3
+                ch = instance["version"][0]
+                self.can_translate = int(ch) > 3 if ch.isnumeric() else False
 
         return self.run_in_thread(_load_instance, done_callback=_done)
 
@@ -497,13 +503,18 @@ class TUI(urwid.Frame):
             in_reply_to_id=in_reply_to_id)
         status = self.make_status(data)
 
-        # TODO: instead of this, fetch new items from the timeline?
-        self.timeline.prepend_status(status)
-        self.timeline.focus_status(status)
+        # TODO: fetch new items from the timeline?
 
         self.footer.set_message("Status posted {} \\o/".format(status.id))
         self.close_overlay()
 
+    def show_account(self, account_id):
+        account = api.whois(self.app, self.user, account_id)
+        self.open_overlay(
+            widget=Account(account),
+            title="Account",
+        )
+
     def async_toggle_favourite(self, timeline, status):
         def _favourite():
             logger.info("Favouriting {}".format(status))
