@@ -1,12 +1,17 @@
 import logging
+import sys
 import urwid
 import webbrowser
 
-from toot.utils import format_content
-from toot.utils.language import language_name
+from typing import Optional
 
+from .entities import Status
+from .scroll import Scrollable, ScrollBar
 from .utils import highlight_hashtags, parse_datetime, highlight_keys
 from .widgets import SelectableText, SelectableColumns
+from toot.utils import format_content
+from toot.utils.language import language_name
+from toot.tui.utils import time_ago
 
 logger = logging.getLogger("toot")
 
@@ -16,6 +21,7 @@ class Timeline(urwid.Columns):
     Displays a list of statuses to the left, and status details on the right.
     """
     signals = [
+        "account",       # Display account info and actions
         "close",         # Close thread
         "compose",       # Compose a new toot
         "delete",        # Delete own status
@@ -43,17 +49,35 @@ class Timeline(urwid.Columns):
         self.can_translate = can_translate
         self.status_list = self.build_status_list(statuses, focus=focus)
         self.followed_tags = followed_tags
+
         try:
-            self.status_details = StatusDetails(statuses[focus], is_thread, can_translate, followed_tags)
+            focused_status = statuses[focus]
         except IndexError:
-            self.status_details = StatusDetails(None, is_thread, can_translate, followed_tags)
+            focused_status = None
+
+        self.status_details = StatusDetails(self, focused_status)
+        status_widget = self.wrap_status_details(self.status_details)
 
         super().__init__([
             ("weight", 40, self.status_list),
             ("weight", 0, urwid.AttrWrap(urwid.SolidFill("│"), "blue_selected")),
-            ("weight", 60, urwid.Padding(self.status_details, left=1)),
+            ("weight", 60, status_widget),
         ])
 
+    def wrap_status_details(self, status_details: "StatusDetails") -> urwid.Widget:
+        """Wrap StatusDetails widget with a scollbar and footer."""
+        return urwid.Padding(
+            urwid.Frame(
+                body=ScrollBar(
+                    Scrollable(urwid.Padding(status_details, right=1)),
+                    thumb_char="\u2588",
+                    trough_char="\u2591",
+                ),
+                footer=self.get_option_text(status_details.status),
+            ),
+            left=1
+        )
+
     def build_status_list(self, statuses, focus):
         items = [self.build_list_item(status) for status in statuses]
         walker = urwid.SimpleFocusListWalker(items)
@@ -74,6 +98,29 @@ class Timeline(urwid.Columns):
             None: "green_selected",
         })
 
+    def get_option_text(self, status: Optional[Status]) -> Optional[urwid.Text]:
+        if not status:
+            return None
+
+        options = [
+            "[A]ccount" if not status.is_mine else "",
+            "[B]oost",
+            "[D]elete" if status.is_mine else "",
+            "B[o]okmark",
+            "[F]avourite",
+            "[V]iew",
+            "[T]hread" if not self.is_thread else "",
+            "[L]inks",
+            "[R]eply",
+            "So[u]rce",
+            "[Z]oom",
+            "Tra[n]slate" if self.can_translate else "",
+            "[H]elp",
+        ]
+        options = "\n" + " ".join(o for o in options if o)
+        options = highlight_keys(options, "white_bold", "cyan")
+        return urwid.Text(options)
+
     def get_focused_status(self):
         try:
             return self.statuses[self.status_list.body.focus]
@@ -104,8 +151,9 @@ class Timeline(urwid.Columns):
         self.draw_status_details(status)
 
     def draw_status_details(self, status):
-        self.status_details = StatusDetails(status, self.is_thread, self.can_translate, self.followed_tags)
-        self.contents[2] = urwid.Padding(self.status_details, left=1), ("weight", 60, False)
+        self.status_details = StatusDetails(self, status)
+        widget = self.wrap_status_details(self.status_details)
+        self.contents[2] = widget, ("weight", 60, False)
 
     def keypress(self, size, key):
         status = self.get_focused_status()
@@ -123,6 +171,10 @@ class Timeline(urwid.Columns):
             if index >= count:
                 self._emit("next")
 
+        if key in ("a", "A"):
+            self._emit("account", status.original.data['account']['id'])
+            return
+
         if key in ("b", "B"):
             self._emit("reblog", status)
             return
@@ -246,19 +298,10 @@ class Timeline(urwid.Columns):
 
 
 class StatusDetails(urwid.Pile):
-    def __init__(self, status, in_thread, can_translate=False, followed_tags=[]):
-        """
-        Parameters
-        ----------
-        status : Status
-            The status to render.
+    def __init__(self, timeline: Timeline, status: Optional[Status]):
+        self.status = status
+        self.followed_tags = timeline.followed_tags
 
-        in_thread : bool
-            Whether the status is rendered from a thread status list.
-        """
-        self.in_thread = in_thread
-        self.can_translate = can_translate
-        self.followed_tags = followed_tags
         reblogged_by = status.author if status and status.reblog else None
         widget_list = list(self.content_generator(status.original, reblogged_by)
             if status else ())
@@ -329,36 +372,18 @@ class StatusDetails(urwid.Pile):
         visibility_color = visibility_colors.get(status.visibility, "gray")
 
         yield ("pack", urwid.Text([
-            ("red", "🠷 ") if status.bookmarked else "",
+            ("blue", f"{status.created_at.strftime('%Y-%m-%d %H:%M')} "),
+            ("red" if status.bookmarked else "gray", "b "),
             ("gray", f"⤶ {status.data['replies_count']} "),
             ("yellow" if status.reblogged else "gray", f"♺ {status.data['reblogs_count']} "),
             ("yellow" if status.favourited else "gray", f"★ {status.data['favourites_count']}"),
             (visibility_color, f" · {visibility}"),
-            ("yellow", f" · Translated from {translated_from} ") if translated_from else "",
+            ("yellow", f" · Translated from {translated_from} " if translated_from else ""),
             ("gray", f" · {application}" if application else ""),
         ]))
 
         # Push things to bottom
-        yield ("weight", 1, urwid.SolidFill(" "))
-
-        options = [
-            "[B]oost",
-            "[D]elete" if status.is_mine else "",
-            "[F]avourite",
-            "B[o]okmark",
-            "[V]iew",
-            "[T]hread" if not self.in_thread else "",
-            "[L]inks",
-            "[R]eply",
-            "So[u]rce",
-            "[Z]oom",
-            "Tra[n]slate" if self.can_translate else "",
-            "[H]elp",
-        ]
-        options = " ".join(o for o in options if o)
-
-        options = highlight_keys(options, "white_bold", "cyan")
-        yield ("pack", urwid.Text(options))
+        yield ("weight", 1, urwid.BoxAdapter(urwid.SolidFill(" "), 1))
 
     def build_linebox(self, contents):
         contents = urwid.Pile(list(contents))
@@ -402,7 +427,17 @@ class StatusDetails(urwid.Pile):
 
 class StatusListItem(SelectableColumns):
     def __init__(self, status):
-        created_at = status.created_at.strftime("%Y-%m-%d %H:%M")
+        edited_at = status.data.get("edited_at")
+
+        # TODO: hacky implementation to avoid creating conflicts for existing
+        # pull reuqests, refactor when merged.
+        created_at = (
+            time_ago(status.created_at).ljust(3, " ")
+            if "--relative-datetimes" in sys.argv
+            else status.created_at.strftime("%Y-%m-%d %H:%M")
+        )
+
+        edited_flag = "*" if edited_at else " "
         favourited = ("yellow", "★") if status.original.favourited else " "
         reblogged = ("yellow", "♺") if status.original.reblogged else " "
         is_reblog = ("cyan", "♺") if status.reblog else " "
@@ -410,6 +445,7 @@ class StatusListItem(SelectableColumns):
 
         return super().__init__([
             ("pack", SelectableText(("blue", created_at), wrap="clip")),
+            ("pack", urwid.Text(("blue", edited_flag))),
             ("pack", urwid.Text(" ")),
             ("pack", urwid.Text(favourited)),
             ("pack", urwid.Text(" ")),
