@@ -1,4 +1,5 @@
 from html.parser import HTMLParser
+import math
 import os
 import re
 import shutil
@@ -7,6 +8,11 @@ import subprocess
 from datetime import datetime, timezone
 
 HASHTAG_PATTERN = re.compile(r'(?<!\w)(#\w+)\b')
+SECOND = 1
+MINUTE = SECOND * 60
+HOUR = MINUTE * 60
+DAY = HOUR * 24
+WEEK = DAY * 7
 
 
 def parse_datetime(value):
@@ -27,6 +33,28 @@ def parse_datetime(value):
     return dttm.astimezone()
 
 
+def time_ago(value: datetime) -> datetime:
+    now = datetime.now().astimezone()
+    delta = now.timestamp() - value.timestamp()
+
+    if (delta < 1):
+        return "now"
+
+    if (delta < 8 * DAY):
+        if (delta < MINUTE):
+            return f"{math.floor(delta / SECOND)}".rjust(2, " ") + "s"
+        if (delta < HOUR):
+            return f"{math.floor(delta / MINUTE)}".rjust(2, " ") + "m"
+        if (delta < DAY):
+            return f"{math.floor(delta / HOUR)}".rjust(2, " ") + "h"
+        return f"{math.floor(delta / DAY)}".rjust(2, " ") + "d"
+
+    if (delta < 53 * WEEK):  # not exactly correct but good enough as a boundary
+        return f"{math.floor(delta / WEEK)}".rjust(2, " ") + "w"
+
+    return ">1y"
+
+
 def highlight_keys(text, high_attr, low_attr=""):
     """
     Takes a string and adds high_attr attribute to parts in square brackets,
